@@ -14,6 +14,9 @@ class Parser:
     def click(self, path: str, element: any=None, timeout: int=0) -> any:
         return self.scraper.click(path=path, element=element, timeout=timeout)
 
+    def click_and_hold(self, path: str, seconds: float, element: any=None, timeout: int=0) -> None:
+        return self.scraper.click_and_hold(path=path, element=element, timeout=timeout, seconds=seconds)
+
     def back(self) -> None:
         self.scraper.back()
 
@@ -38,8 +41,8 @@ class Parser:
     def login(self, username_text: str=None, username: str=None, password_text: str=None, password: str=None) -> None:
         self.scraper.login(username_text, username, password_text, password)
 
-    def search(self, path: str=None, text: str=None) -> None:
-        self.scraper.search(path, text)
+    def search(self, path: str=None, text: str=None, timeout: int=0) -> None:
+        self.scraper.search(path=path, text=text, timeout=timeout)
 
     def scroll_to_bottom(self) -> None:
         self.scraper.scroll_to_bottom()
