@@ -202,9 +202,12 @@ class Scraper:
     def enter_text(self, path: str, text: str, element: any=None, clear: bool=False, timeout: int=0):
         return self.on_enter_text(path=path, text=text, element=element, clear=clear, timeout=timeout)
 
-    def click(self, path, element=None, timeout=0):
+    def click(self, path: str, element: any=None, timeout: int=0) -> any:
         return self.on_click(path=path, element=element, timeout=timeout)
 
+    def click_and_hold(self, path: str, seconds: float, element: any=None, timeout: int=0) -> None:
+        self.click_and_hold(path=path, seconds=seconds, element=element, timeout=timeout)
+
     def back(self):
         self.on_back()
 
@@ -220,8 +223,8 @@ class Scraper:
     def login(self, username_text=None, username=None, password_text=None, password=None):
         return self.on_login(username_text, username, password_text, password)
 
-    def search(self, path=None, text=None):
-        return self.on_search(path, text)
+    def search(self, path=None, text=None, timeout: int=0):
+        return self.on_search(path=path, text=text, timeout=timeout)
 
     def scroll_to_bottom(self):
         return self.on_scroll_to_bottom()
