@@ -1,3 +1,4 @@
+import time
 from scrapeanything.scraper.scraper import Scraper
 from scrapeanything.utils.config import Config
 
@@ -128,29 +129,62 @@ class Selenium(Scraper):
         else:
             return None
 
-    def click(self, path: str, element: any=None, timeout=0):
-        element = self.xPath(path=path, element=element, timeout=timeout)
+    def on_click_and_hold(self, path: str, seconds: float, element: any=None, timeout: int=0) -> None:
+        element = self.xPath(path=path, timeout=timeout)
+        action = ActionChains(self.scraper.driver)
+        action.click_and_hold(element).perform()
+        time.sleep(seconds) # sleep for N seconds
+        action.release().perform()
 
+    def on_click(self, path: str, element: any=None, timeout: int=0) -> any:
+        if element is None and path is not None:
+            element = self.xPath(path=path, element=element, timeout=timeout)
+        
         if element is not None:
             if type(element) is list:
-                element = element[0]
-
+                if len(element) > 0:
+                    element = element[0]
+                else:
+                    return None
             try:
                 element.click()
             except Exception as e:
                 try:
-                    self.driver.execute_script("arguments[0].click();", element)
-                except:
+                    self.scraper.driver.execute_script("arguments[0].click();", element)
+                except Exception as e:
                     try:
-                        actions = ActionChains(self.driver)
+                        actions = ActionChains(self.scraper.driver)
                         actions.click(element).perform()
-                    except:
+                    except Exception as e:
                         return None
 
-            return element
+                return element
         else:
             return None
 
+    # def click(self, path: str, element: any=None, timeout=0):
+    #     element = self.xPath(path=path, element=element, timeout=timeout)
+
+    #     if element is not None:
+    #         if type(element) is list:
+    #             element = element[0]
+
+    #         try:
+    #             element.click()
+    #         except Exception as e:
+    #             try:
+    #                 self.driver.execute_script("arguments[0].click();", element)
+    #             except:
+    #                 try:
+    #                     actions = ActionChains(self.driver)
+    #                     actions.click(element).perform()
+    #                 except:
+    #                     return None
+
+    #         return element
+    #     else:
+    #         return None
+
     def on_back(self):
         self.driver.back()
 
@@ -181,9 +215,9 @@ class Selenium(Scraper):
 
         self.on_click('//button[@class="sign-in-form__submit-button"]')
 
-    def on_search(self, path=None, text=None):
-        self.on_enter_text(path, text)
-        return self.on_enter_text(path, Keys.RETURN)
+    def on_search(self, path=None, text=None, timeout: int=0):
+        self.on_enter_text(path=path, text=text, timeout=timeout)
+        return self.on_enter_text(path=path, text=Keys.RETURN, timeout=timeout)
 
     def on_scroll_to_bottom(self):
         self.driver.execute_script('window.scrollTo(0, document.body.scrollHeight);')
